// Header file
#pragma chip PIC17C766, core 16 b, code 16384, ram 26 : 0x3FF

/* Predefined:
INDF0, FSR0,
PCL, PCLATH,
ALUSTA, T0STA, CPUSTA, INTSTA,
INDF1, FSR1,
WREG,
TMR0L, TMR0H,
TBLPTR, TBLPTRL, TBLPTRH,
BSR, BSRL, BSRH,
PRODL, PRODH,
Carry,DC,Zero_,Overflow
*/

char PORTA    @ 0x10;
char DDRB     @ 0x11;
char PORTB    @ 0x12;
char RCSTA1   @ 0x13;
char RCREG1   @ 0x14;
char TXSTA1   @ 0x15;
char TXREG1   @ 0x16;
char SPBRG1   @ 0x17;

char DDRC     @ 0x110;
char PORTC    @ 0x111;
char DDRD     @ 0x112;
char PORTD    @ 0x113;
char DDRE     @ 0x114;
char PORTE    @ 0x115;
char PIR1     @ 0x116;
char PIE1     @ 0x117;

char TMR1     @ 0x210;
char TMR2     @ 0x211;
char TMR3L    @ 0x212;
char TMR3H    @ 0x213;
char PR1      @ 0x214;
char PR2      @ 0x215;
char PR3L     @ 0x216;
char CA1L     @ 0x216;
char PR3H     @ 0x217;
char CA1H     @ 0x217;

char PW1DCL   @ 0x310;
char PW2DCL   @ 0x311;
char PW1DCH   @ 0x312;
char PW2DCH   @ 0x313;
char CA2L     @ 0x314;
char CA2H     @ 0x315;
char TCON1    @ 0x316;
char TCON2    @ 0x317;

char PIR2     @ 0x410;
char PIE2     @ 0x411;

char RCSTA2   @ 0x413;
char RCREG2   @ 0x414;
char TXSTA2   @ 0x415;
char TXREG2   @ 0x416;
char SPBRG2   @ 0x417;

char DDRF     @ 0x510;
char PORTF    @ 0x511;
char DDRG     @ 0x512;
char PORTG    @ 0x513;
char ADCON0   @ 0x514;
char ADCON1   @ 0x515;
char ADRESL   @ 0x516;
char ADRESH   @ 0x517;

char SSPADD   @ 0x610;
char SSPCON1  @ 0x611;
char SSPCON2  @ 0x612;
char SSPSTAT  @ 0x613;
char SSPBUF   @ 0x614;

char PW3DCL   @ 0x710;
char PW3DCH   @ 0x711;
char CA3L     @ 0x712;
char CA3H     @ 0x713;
char CA4L     @ 0x714;
char CA4H     @ 0x715;
char TCON3    @ 0x716;

char DDRH     @ 0x810;
char PORTH    @ 0x811;
char DDRJ     @ 0x812;
char PORTJ    @ 0x813;


bit T0PS0  @ T0STA.1;
bit T0PS1  @ T0STA.2;
bit T0PS2  @ T0STA.3;
bit T0PS3  @ T0STA.4;
bit T0CS   @ T0STA.5;
bit T0SE   @ T0STA.6;
bit INTEDG @ T0STA.7;

bit BOR_   @ CPUSTA.0;
bit POR_   @ CPUSTA.1;
bit PD     @ CPUSTA.2;
bit TO     @ CPUSTA.3;
bit GLINTD @ CPUSTA.4;
bit STKAV  @ CPUSTA.5;

bit INTE   @ INTSTA.0;
bit T0IE   @ INTSTA.1;
bit T0CKIE @ INTSTA.2;
bit PEIE   @ INTSTA.3;
bit INTF   @ INTSTA.4;
bit T0IF   @ INTSTA.5;
bit T0CKIF @ INTSTA.6;
bit PEIF   @ INTSTA.7;

bit INT    @ PORTA.0;
bit T0CKI  @ PORTA.1;
bit SCL    @ PORTA.2;
bit SS_    @ PORTA.2;
bit SDA    @ PORTA.3;
bit SDI    @ PORTA.3;
bit DT1    @ PORTA.4;
bit RX1    @ PORTA.4;
bit CK1    @ PORTA.5;
bit TX1    @ PORTA.5;
bit RBPU_  @ PORTA.7;

bit CAP1   @ PORTB.0;
bit CAP2   @ PORTB.1;
bit PWM1   @ PORTB.2;
bit PWM2   @ PORTB.3;
bit TCLK12 @ PORTB.4;
bit TCLK3  @ PORTB.5;
bit SCK    @ PORTB.6;
bit SDO    @ PORTB.7;

bit RX9D1  @ RCSTA1.0;
bit OERR1  @ RCSTA1.1;
bit FERR1  @ RCSTA1.2;
bit CREN1  @ RCSTA1.4;
bit SREN1  @ RCSTA1.5;
bit RX9_1  @ RCSTA1.6;
bit SPEN1  @ RCSTA1.7;

bit TX9D1  @ TXSTA1.0;
bit TRMT1  @ TXSTA1.1;
bit SYNC1  @ TXSTA1.4;
bit TXEN1  @ TXSTA1.5;
bit TX9_1  @ TXSTA1.6;
bit CSRC1  @ TXSTA1.7;

bit AD0    @ PORTC.0;
bit AD1    @ PORTC.1;
bit AD2    @ PORTC.2;
bit AD3    @ PORTC.3;
bit AD4    @ PORTC.4;
bit AD5    @ PORTC.5;
bit AD6    @ PORTC.6;
bit AD7    @ PORTC.7;

bit AD8    @ PORTD.0;
bit AD9    @ PORTD.1;
bit AD10   @ PORTD.2;
bit AD11   @ PORTD.3;
bit AD12   @ PORTD.4;
bit AD13   @ PORTD.5;
bit AD14   @ PORTD.6;
bit AD15   @ PORTD.7;

bit ALE    @ PORTE.0;
bit OE_    @ PORTE.1;
bit WR_    @ PORTE.2;
bit CAP4   @ PORTE.3;

bit RC1IF  @ PIR1.0;
bit TX1IF  @ PIR1.1;
bit CA1IF  @ PIR1.2;
bit CA2IF  @ PIR1.3;
bit TMR1IF @ PIR1.4;
bit TMR2IF @ PIR1.5;
bit TMR3IF @ PIR1.6;
bit RBIF   @ PIR1.7;

bit RC1IE  @ PIE1.0;
bit TX1IE  @ PIE1.1;
bit CA1IE  @ PIE1.2;
bit CA2IE  @ PIE1.3;
bit TMR1IE @ PIE1.4;
bit TMR2IE @ PIE1.5;
bit TMR3IE @ PIE1.6;
bit RBIE   @ PIE1.7;

bit TM2PW2 @ PW2DCL.5;

bit TMR1CS @ TCON1.0;
bit TMR2CS @ TCON1.1;
bit TMR3CS @ TCON1.2;
bit T16    @ TCON1.3;
bit CA1ED0 @ TCON1.4;
bit CA1ED1 @ TCON1.5;
bit CA2ED0 @ TCON1.6;
bit CA2ED1 @ TCON1.7;

bit TMR1ON @ TCON2.0;
bit TMR2ON @ TCON2.1;
bit TMR3ON @ TCON2.2;
bit CA1_PR3@ TCON2.3;
bit PWM1ON @ TCON2.4;
bit PWM2ON @ TCON2.5;
bit CA1OVF @ TCON2.6;
bit CA2OVF @ TCON2.7;

bit RC2IF  @ PIR2.0;
bit TX2IF  @ PIR2.1;
bit CA3IF  @ PIR2.2;
bit CA4IF  @ PIR2.3;
bit ADIF   @ PIR2.5;
bit BCLIF  @ PIR2.6;
bit SSPIF  @ PIR2.7;

bit RC2IE  @ PIE2.0;
bit TX2IE  @ PIE2.1;
bit CA3IE  @ PIE2.2;
bit CA4IE  @ PIE2.3;
bit ADIE   @ PIE2.5;
bit BCLIE  @ PIE2.6;
bit SSPIE  @ PIE2.7;

bit RX9D2  @ RCSTA2.0;
bit OERR2  @ RCSTA2.1;
bit FERR2  @ RCSTA2.2;
bit CREN2  @ RCSTA2.4;
bit SREN2  @ RCSTA2.5;
bit RX9_2  @ RCSTA2.6;
bit SPEN2  @ RCSTA2.7;

bit TX9D2  @ TXSTA2.0;
bit TRMT2  @ TXSTA2.1;
bit SYNC2  @ TXSTA2.4;
bit TXEN2  @ TXSTA2.5;
bit TX9_2  @ TXSTA2.6;
bit CSRC2  @ TXSTA2.7;

bit AN4    @ PORTF.0;
bit AN5    @ PORTF.1;
bit AN6    @ PORTF.2;
bit AN7    @ PORTF.3;
bit AN8    @ PORTF.4;
bit AN9    @ PORTF.5;
bit AN10   @ PORTF.6;
bit AN11   @ PORTF.7;

bit AN3    @ PORTG.0;
bit AN2    @ PORTG.1;
bit AN1    @ PORTG.2;
bit AN0    @ PORTG.3;
bit CAP3   @ PORTG.4;
bit PWM3   @ PORTG.5;
bit RX2    @ PORTG.6;
bit DT2    @ PORTG.6;
bit TX2    @ PORTG.7;
bit CK2    @ PORTG.7;

bit ADON   @ ADCON0.0;
bit GO     @ ADCON0.2;
bit CHS0   @ ADCON0.4;
bit CHS1   @ ADCON0.5;
bit CHS2   @ ADCON0.6;
bit CHS3   @ ADCON0.7;

bit PCFG0  @ ADCON1.0;
bit PCFG1  @ ADCON1.1;
bit PCFG2  @ ADCON1.2;
bit PCFG3  @ ADCON1.3;
bit ADFM   @ ADCON1.5;
bit ADCS0  @ ADCON1.6;
bit ADCS1  @ ADCON1.7;

bit SSPM0  @ SSPCON1.0;
bit SSPM1  @ SSPCON1.1;
bit SSPM2  @ SSPCON1.2;
bit SSPM3  @ SSPCON1.3;
bit CKP    @ SSPCON1.4;
bit SSPEN  @ SSPCON1.5;
bit SSPOV  @ SSPCON1.6;
bit WCOL   @ SSPCON1.7;

bit SEN    @ SSPCON2.0;
bit RSEN   @ SSPCON2.1;
bit PEN    @ SSPCON2.2;
bit RCEN   @ SSPCON2.3;
bit ACKEN  @ SSPCON2.4;
bit ACKDT  @ SSPCON2.5;
bit ACKSTAT@ SSPCON2.6;
bit GCEN   @ SSPCON2.7;

bit BF     @ SSPSTAT.0;
bit UA     @ SSPSTAT.1;
bit RW_    @ SSPSTAT.2;
bit S      @ SSPSTAT.3;
bit P      @ SSPSTAT.4;
bit DA_    @ SSPSTAT.5;
bit CKE    @ SSPSTAT.6;
bit SMP    @ SSPSTAT.7;

bit TM2PW3 @ PW3DCL.5;

bit PWM3ON @ TCON3.0;
bit CA3ED0 @ TCON3.1;
bit CA3ED1 @ TCON3.2;
bit CA4ED0 @ TCON3.3;
bit CA4ED1 @ TCON3.4;
bit CA3OVF @ TCON3.5;
bit CA4OVF @ TCON3.6;

bit AN12   @ PORTH.4;
bit AN13   @ PORTH.5;
bit AN14   @ PORTH.6;
bit AN15   @ PORTH.7;
